@@ -64,6 +64,7 @@ def read_psi_ascii(
                 time = float(m.group(1))
                 times.append(time)
             elif line.startswith("$psi"):
+                tape_finished = True
                 psis.append([])
                 match = RE_ELEMENT.match(fhandle.readline())
                 while match:
@@ -129,7 +130,7 @@ def read_psi_frame_ascii(
         raise KeyError("index {} is out of bounds".format(index))
 
     return numpy.array(tape, dtype=numpy.int64), numpy.array(
-        [times[index]]), numpy.array(psi, dtype=numpy.complex128)
+        times[index]), numpy.array(psi, dtype=numpy.complex128)
 
 
 def read_psi_hdf5(path):
